Struct WpTearingControlManagerV1
pub struct WpTearingControlManagerV1 { /* private fields */ }wayland and Linux only.Expand description
protocol for tearing control
For some use cases like games or drawing tablets it can make sense to reduce latency by accepting tearing with the use of asynchronous page flips. This global is a factory interface, allowing clients to inform which type of presentation the content of their surfaces is suitable for.
Graphics APIs like EGL or Vulkan, that manage the buffer queue and commits of a wl_surface themselves, are likely to be using this extension internally. If a client is using such an API for a wl_surface, it should not directly use this extension on that surface, to avoid raising a tearing_control_exists protocol error.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
This interface has no events.
Implementations
impl WpTearingControlManagerV1
impl WpTearingControlManagerV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy tearing control factory object
Destroy this tearing control factory object. Other objects, including wp_tearing_control_v1 objects created by this factory, are not affected by this request.
pub fn get_tearing_control<U, D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> WpTearingControlV1
pub fn get_tearing_control<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> WpTearingControlV1
extend surface interface for tearing control
Instantiate an interface extension for the given wl_surface to request asynchronous page flips for presentation.
If the given wl_surface already has a wp_tearing_control_v1 object associated, the tearing_control_exists protocol error is raised.